@@ -7,6 +7,17 @@ download_dir = osp.expanduser('~/.skrobot')
 data_dir = osp.abspath(osp.dirname(__file__))
 
 
+def bunny_objpath():
+    target_path = osp.join(download_dir, 'mesh', 'bunny.obj')
+    gdown.cached_download(
+        url='https://drive.google.com/uc?id=18aAYzBglAGaSwes6oAENcufD8KC5XDph',
+        path=target_path,
+        md5='19bd31bde1fcf5242a8a82ed4ac03c72',
+        quiet=True,
+    )
+    return target_path
+
+
 def fetch_urdfpath():
     gdown.cached_download(
         url='https://drive.google.com/uc?id=1y7Jc3QoVW6J072CrSNupfKpyLp4NNxuH',
@@ -15,11 +26,11 @@ def fetch_urdfpath():
         postprocess=gdown.extractall,
         quiet=True,
     )
-    return osp.join(download_dir, 'fetch_description/fetch.urdf')
+    return osp.join(download_dir, 'fetch_description', 'fetch.urdf')
 
 
 def kuka_urdfpath():
-    return osp.join(data_dir, 'kuka_description/kuka.urdf')
+    return osp.join(data_dir, 'kuka_description', 'kuka.urdf')
 
 
 def panda_urdfpath():
@@ -30,7 +41,7 @@ def panda_urdfpath():
         postprocess=gdown.extractall,
         quiet=True,
     )
-    return osp.join(download_dir, 'franka_description/panda.urdf')
+    return osp.join(download_dir, 'franka_description', 'panda.urdf')
 
 
 def pr2_urdfpath():
@@ -41,4 +52,4 @@ def pr2_urdfpath():
         postprocess=gdown.extractall,
         quiet=True,
     )
-    return osp.join(download_dir, 'pr2_description/pr2.urdf')
+    return osp.join(download_dir, 'pr2_description', 'pr2.urdf')
